@@ -1,18 +1,18 @@
 import logging
-from typing import List
+from typing import Optional
 
+from peek_abstract_chunked_index.private.server.client_handlers.ACIChunkLoadRpcABC import \
+    ACIChunkLoadRpcABC
 from peek_plugin_base.PeekVortexUtil import peekServerName, peekClientName
-from peek_plugin_base.storage.DbConnection import DbSessionCreator
 from peek_plugin_graphdb._private.PluginNames import graphDbFilt
-from peek_plugin_graphdb._private.storage.ItemKeyIndexEncodedChunk import ItemKeyIndexEncodedChunk
+from peek_plugin_graphdb._private.storage.ItemKeyIndexEncodedChunk import \
+    ItemKeyIndexEncodedChunk
 from vortex.rpc.RPC import vortexRPC
 
 logger = logging.getLogger(__name__)
 
 
-class ItemKeyIndexChunkLoadRpc:
-    def __init__(self, dbSessionCreator: DbSessionCreator):
-        self._dbSessionCreator = dbSessionCreator
+class ItemKeyIndexChunkLoadRpc(ACIChunkLoadRpcABC):
 
     def makeHandlers(self):
         """ Make Handlers
@@ -29,22 +29,11 @@ class ItemKeyIndexChunkLoadRpc:
     # -------------
     @vortexRPC(peekServerName, acceptOnlyFromVortex=peekClientName, timeoutSeconds=60,
                additionalFilt=graphDbFilt, deferToThread=True)
-    def loadItemKeyIndexChunks(self, offset: int, count: int) -> List[ItemKeyIndexEncodedChunk]:
+    def loadItemKeyIndexChunks(self, offset: int, count: int) -> Optional[bytes]:
         """ Update Page Loader Status
 
         Tell the server of the latest status of the loader
 
         """
-        session = self._dbSessionCreator()
-        try:
-            chunks = (session
-                      .query(ItemKeyIndexEncodedChunk)
-                      .order_by(ItemKeyIndexEncodedChunk.id)
-                      .offset(offset)
-                      .limit(count)
-                      .yield_per(count))
-
-            return list(chunks)
-
-        finally:
-            session.close()
+        return self.ckiInitialLoadChunksPayloadBlocking(offset, count,
+                                                        ItemKeyIndexEncodedChunk)
