@@ -17,3 +17,15 @@ class GraphDbEncodedChunkTuple(Tuple):
     encodedData: bytes = TupleField()
     encodedHash: str = TupleField()
     lastUpdate: str = TupleField()
+
+    @property
+    def ckiChunkKey(self):
+        return self.chunkKey
+
+    @property
+    def ckiHasEncodedData(self) -> bool:
+        return bool(self.encodedData)
+
+    @property
+    def ckiLastUpdate(self):
+        return self.lastUpdate
