@@ -1,11 +1,13 @@
 from typing import Dict
 
+from peek_abstract_chunked_index.private.tuples.ACIUpdateDateTupleABC import \
+    ACIUpdateDateTupleABC
 from peek_plugin_graphdb._private.PluginNames import graphDbTuplePrefix
 from vortex.Tuple import addTupleType, TupleField, Tuple
 
 
 @addTupleType
-class ItemKeyIndexUpdateDateTuple(Tuple):
+class ItemKeyIndexUpdateDateTuple(Tuple, ACIUpdateDateTupleABC):
     """ ItemKeyIndex Object Update Date Tuple
 
     This tuple represents the state of the chunks in the cache.
@@ -19,3 +21,8 @@ class ItemKeyIndexUpdateDateTuple(Tuple):
 
     initialLoadComplete: bool = TupleField()
     updateDateByChunkKey: Dict[str, str] = TupleField({})
+
+    @property
+    def ckiUpdateDateByChunkKey(self):
+        return self.updateDateByChunkKey
+
